Module tensor

Module tensor 

Tensor type — a lazy handle to a node in the computation graph.

Operations on tensors record nodes in the graph. Actual computation is deferred until eval() (or to_vec_f32()) is called, at which point the stream topologically sorts the subgraph and dispatches to the backend.

Structs

Tensor
A tensor handle.

Enums

Device
Compute device.